xquery version "1.0";

(: namespaces :)
declare namespace request = "http://exist-db.org/xquery/request";
declare namespace response = "http://exist-db.org/xquery/response";
declare namespace transform = "http://exist-db.org/xquery/transform";
declare namespace util = "http://exist-db.org/xquery/util";
declare namespace dc = "http://purl.org/dc/elements/1.1/";
declare namespace x = "http://exist.sourceforge.net/dc-ext";

(: serialize output to XHTML :)
declare option exist:serialize "method=xhtml indent=yes omit-xml-declaration=no doctype-public=-//W3C//DTD&#160;XHTML&#160;1.1//EN";

declare variable $books_collection as xs:string { "/db/oxford/books" };
declare variable $books_xslt as xs:string { "/db/oxford/books.xslt" };


(: performs a search :)
declare function local:search() as node()*
{
    (: get the keywords :)
    let $keywords := request:get-parameter("keywords", ()) return
        
        (: were keywords specified :)
        if(empty($keywords))then
        (
            (: no - redirect to the homepage :)
            response:redirect-to(xs:anyURI("4_xslt_output.xql"))
        )
        else
        (
            (: yes, peform the search against title and description :)
            (: |= indicates an OR search of the terms :)
            (: &= indicates an AND search of the terms :)
            let $books := collection($books_collection)/book[dc:title |= $keywords or dc:title |= $keywords] return
                transform:transform(<books>{$books}</books>, doc($books_xslt), ())
        )
};

(: home page :)
declare function local:home() as node()
{
    <div>
        <h1>Books Example</h1>
        <p>Currently there are <span style="color:green">{count(collection($books_collection)/book)}</span> books in the collection</p>
        <br/>
        <h2>Keyword Search</h2>
        <form method="post" action="?action=search">
            Keywords: <input name="keywords" type="text"/>
        </form>
    </div>
};


(: execution starts here -  call the function named by the action or default to the function called "home" :)
<html>
    <head>
        <title>Books Example</title>
    </head>
    <body>
    {
        let $funAction := concat("local:", request:get-parameter("action", "home"), "()") return
            util:eval($funAction)
    }
    </body>
</html>